@@ -187,10 +187,15 @@ class IPPlugin(hildondesktop.HomeItem):
 			where = ' WHERE ((start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'"'
 			where = where + ' AND end>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'")'
 			#reccuring
+#			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Day(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND ((julianday("'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'")-(julianday(start))) % repeatvalue)=0.0 ) '
+#			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Week(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND ((julianday("'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'")-(julianday(start))) % (repeatvalue*7))=0.0 ) '
+#			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Month(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)='+str(self.view_datetime.day)+' AND (('+str((self.view_datetime.year*12)+self.view_datetime.month)+'-(strftime("%m",start)+(strftime("%Y",start)*12))) % (repeatvalue))==0 ) '
+#			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Year(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)='+str(self.view_datetime.day)+' AND strftime("%m",start)='+str(self.view_datetime.month)+' AND (('+str((self.view_datetime.year))+'-((strftime("%Y",start)))) % (repeatvalue))==0 ) '
 			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Day(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND ((julianday("'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'")-(julianday(start))) % repeatvalue)=0.0 ) '
 			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Week(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND ((julianday("'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'")-(julianday(start))) % (repeatvalue*7))=0.0 ) '
 			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Month(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)='+str(self.view_datetime.day)+' AND (('+str((self.view_datetime.year*12)+self.view_datetime.month)+'-(strftime("%m",start)+(strftime("%Y",start)*12))) % (repeatvalue))==0 ) '
 			where = where + ' OR (start<="'+self.view_datetime.strftime("%Y-%m-%d 23:59")+'" AND repeat=1 AND frequency="Year(s)" AND until>="'+self.view_datetime.strftime("%Y-%m-%d 00:00")+'" AND strftime("%d",start)='+str(self.view_datetime.day)+' AND strftime("%m",start)='+str(self.view_datetime.month)+' AND (('+str((self.view_datetime.year))+'-((strftime("%Y",start)))) % (repeatvalue))==0 ) '
+
 			where = where + ')'
 
 			dbcur.execute('SELECT  start, end, description,uuid,repeat,repeatvalue,frequency,until FROM events  '+where + '  AND description<>"DELETED" ORDER by start')       
@@ -210,26 +215,26 @@ class IPPlugin(hildondesktop.HomeItem):
 			    if frequency=="Day(s)":
 			      diff = datetime.timedelta(days=repeatvalue)
 			      d = start_datetime
-			      while (d <= until) and (d.date() <= self.view_datetime.date()):
+			      while (d.date() <= until.date()) and (d.date() <= self.view_datetime.date()):
 			        if d.date() == self.view_datetime.date():
 			  			  text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Week(s)":
 			      diff = datetime.timedelta(days=repeatvalue*7)
 			      d = start_datetime
-			      while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
 			        if d.strftime("%W")==self.view_datetime.strftime("%W"):
 			          text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Month(s)":
 			      d = start_datetime
-			      while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
 			        if d.strftime("%W")==self.view_datetime.strftime("%W"):
 			          text = text + '\n'+d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = addMonth(d,repeatvalue) 
 			    elif frequency=="Year(s)":
 			      d = start_datetime
-			      while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
 			        if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W")):
 			          text = text + '\n'+d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = addMonth(d,repeatvalue*12) 
@@ -262,26 +267,26 @@ class IPPlugin(hildondesktop.HomeItem):
 			    if frequency=="Day(s)":
 			      diff = datetime.timedelta(days=repeatvalue)
 			      d = start_datetime
-			      while (d <= until) and (d.date() <= self.view_datetime.date()):
+			      while (d.date() <= until.date()) and (d.date() <= self.view_datetime.date()):
 			        if d.date() == self.view_datetime.date():
 			  			  text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Week(s)":
 			      diff = datetime.timedelta(days=repeatvalue*7)
 			      d = start_datetime
-			      while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
 			        if d.strftime("%W")==self.view_datetime.strftime("%W"):
 			          text = text +'\n'+ d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = d+diff
 			    elif frequency=="Month(s)":
 			      d = start_datetime
-			      while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
 			        if d.strftime("%W")==self.view_datetime.strftime("%W"):
 			          text = text + '\n'+d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = addMonth(d,repeatvalue) 
 			    elif frequency=="Year(s)":
 			      d = start_datetime
-			      while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
+			      while (d.date() <= until.date()) and (d <= getWeekDetails(self.view_datetime)[1]):
 			        if (d.strftime("%Y")==self.view_datetime.strftime("%Y")) and (d.strftime("%W")==self.view_datetime.strftime("%W")):
 			          text = text + '\n'+d.strftime(WEEK_VIEW_FORMAT)+':'+event[2]
 			        d = addMonth(d,repeatvalue*12) 
